@@ -115,7 +115,7 @@ from typing import get_type_hints
 
 from refinery.lib.frame import Chunk
 from refinery.lib.tools import isbuffer, infinitize, one
-from refinery.lib.meta import metavars
+from refinery.lib.meta import is_valid_variable_name, metavars
 
 FinalType = TypeVar('FinalType')
 
@@ -228,7 +228,7 @@ class SliceAgain(LazyEvaluation):
     Raised by `refinery.lib.argformats.sliceobj` to indicate that meta variables
     are required to compue this slice.
     """
-    def __init__(self, expr):
+    def __init__(self, expr: Union[DelayedBinaryArgument, str]):
         self.expr = expr
 
     def __call__(self, data):
@@ -249,15 +249,18 @@ def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = Non
         return expression
     if isinstance(expression, int):
         return slice(expression, expression + 1)
-    try:
-        expression = DelayedBinaryArgument(expression)
-        expression = expression()
-    except TooLazy:
-        return SliceAgain(expression)
+    if isinstance(expression, (bytes, bytearray)):
+        expression = expression.decode('utf8')
+
+    if is_valid_variable_name(expression):
+        try:
+            return sliceobj(variables[expression], variables, range)
+        except (KeyError, TypeError):
+            return SliceAgain(expression)
 
-    expression = expression.decode('utf8')
     expression = expression or ':'
     sliced = expression.split(':')
+
     if not sliced or len(sliced) > 3:
         raise ArgumentTypeError(F'the expression {expression} is not a valid slice.')
     try:
@@ -674,14 +677,12 @@ class DelayedArgument(LazyEvaluation):
                 return stream.read(bounds.stop)
         try:
             path: Path = one(Path.cwd().glob(pattern))
-        except NotImplementedError:
+        except (NotImplementedError, LookupError):
             path: Path = Path(pattern)
-        except LookupError:
-            path = None
-        if not path or not path.exists() or not path.is_file():
-            raise ArgumentTypeError(F'File not found: {pattern}')
         try:
             return read()
+        except FileNotFoundError:
+            raise ArgumentTypeError(F'File not found: {pattern}')
         except ParserVariableMissing:
             return read
 
@@ -733,7 +734,7 @@ class DelayedArgument(LazyEvaluation):
         return extract
 
     def _interpret_variable(self, name: str, obj: Any):
-        if isbuffer(obj) or isinstance(obj, int):
+        if isbuffer(obj) or isinstance(obj, int) or obj is None:
             return obj
         if isinstance(obj, str):
             return utf8(obj)
@@ -1044,6 +1045,8 @@ class DelayedBinaryArgument(DelayedArgument):
         if not isbuffer(value):
             if isinstance(value, str):
                 return value.encode('utf8')
+            if not value:
+                return B''
             raise ArgumentTypeError(
                 F'The expression {self.expression} returned a value of type {type(value).__name__}, '
                 R'which could not be converted to a byte string.'
@@ -1058,8 +1061,8 @@ class DelayedNumSeqArgument(DelayedArgument):
     attempts to evalue the input as a Python expression.
     """
 
-    def __init__(self, expression: str, typecheck=True):
-        super().__init__(expression)
+    def __init__(self, expression: str, reverse=False, seed=None, typecheck=True):
+        super().__init__(expression, reverse, seed)
         self.typecheck = typecheck
 
     def default_handler(self, expression: str) -> Iterable[int]:
@@ -1263,19 +1266,19 @@ expressions.
 """
 
 
-def numseq(expression: Union[int, str], typecheck=True) -> Union[Iterable[int], DelayedNumSeqArgument]:
+def numseq(expression: Union[int, str], reverse=False, seed=None, typecheck=True) -> Union[Iterable[int], DelayedNumSeqArgument]:
     """
     This is the argument parser type that uses `refinery.lib.argformats.DelayedNumSeqArgument`.
     """
     if isinstance(expression, int):
         return RepeatedInteger(expression)
-    arg = DelayedNumSeqArgument(expression, typecheck)
+    arg = DelayedNumSeqArgument(expression, reverse=reverse, seed=seed, typecheck=typecheck)
     with suppress(TooLazy):
         return arg()
     return arg
 
 
-def multibin(expression: Union[str, bytes, bytearray], reverse: bool = False, seed=None) -> Union[bytes, DelayedArgument]:
+def multibin(expression: Union[str, bytes, bytearray], reverse=False, seed=None) -> Union[bytes, DelayedArgument]:
     """
     This is the argument parser type that uses `refinery.lib.argformats.DelayedBinaryArgument`.
     """
