@@ -14,6 +14,7 @@ from .lznt1  import lznt1  # noqa
 from .lzo    import lzo    # noqa
 from .szdd   import szdd   # noqa
 from .zl     import zl     # noqa
+from .qlz    import qlz    # noqa
 
 
 class decompress(Unit):
@@ -44,7 +45,7 @@ class decompress(Unit):
             raise ValueError('The compression factor must be nonnegative.')
         super().__init__(tolerance=tolerance, prepend=prepend, min_ratio=min_ratio)
         self.engines = [
-            engine() for engine in [szdd, zl, lzma, aplib, jcalg, bz2, blz, lzjb, lz4, lzo, lznt1]
+            engine() for engine in [szdd, zl, lzma, aplib, qlz, jcalg, bz2, blz, lzjb, lz4, lzo, lznt1]
         ]
 
     def process(self, data):
