@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units.pattern import arg, RegexUnit
+from refinery.units.pattern import Arg, RegexUnit
 from refinery.units.meta import ConditionalUnit
 
 
@@ -11,7 +11,7 @@ class iffx(RegexUnit, ConditionalUnit):
     """
     def __init__(
         self, regex, multiline=False, ignorecase=False, negate=False, temporary=False,
-        match: arg.switch('-m',
+        match: Arg.Switch('-m',
             help='Perform a full match rather than matching anywhere in the chunk.') = False
     ):
         super().__init__(regex=regex, negate=negate, temporary=temporary, multiline=multiline, ignorecase=ignorecase, match=match)
